
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.008.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "A client for the ORCID 2.0 API",
  "dist_author" => [
    "Patrick Hochstenbach C<< <patrick.hochstenbach at ugent.be> >>"
  ],
  "dist_name" => "WWW-ORCID",
  "dist_version" => "0.03_02",
  "license" => "perl",
  "module_name" => "WWW::ORCID",
  "recommends" => {
    "JSON::XS" => "2.3"
  },
  "recursive_test_files" => 1,
  "requires" => {
    "Class::Load" => 0,
    "HTTP::Tiny" => 0,
    "JSON" => "2.51",
    "LWP::UserAgent" => 0,
    "Log::Any" => 0,
    "Moo" => "1.000008",
    "Sub::Quote" => 0,
    "URI" => 0,
    "namespace::clean" => 0
  },
  "test_requires" => {
    "Test::Deep" => 0,
    "Test::Exception" => 0,
    "Test::More" => 0,
    "Test::Pod" => 0
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Test::Deep" => 0,
  "Test::Exception" => 0,
  "Test::More" => 0,
  "Test::Pod" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
